%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% Function to evaluate the indoor position estimations for the evaluation logile
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%	NAME:	evaluate2018
%	INPUT:	solutionname	-> File with the estimations (see below)
%	OUTPUT:	metric 			-> Evaluation metric with 2 decimal digits
%
% example: 
%
% 	evaluate2018('sample_results_01')
%
%		ans: 
%
%	INPUT: File with the estimations
%
% 	File 'sampler_results_01.csv' must be located inside folder estimations
%	
%	  The row format for the csv files is:
%		  timestamp, longitude, latitude, floor, keypoint
%		
%		  timestamps must be provided with a frequence of 2hz starting
%		  from apptimestamp 0 and ending at the last apptimestamp. In 2018
%     	  timestamp is provided as Unixtime in ms, so the first estimation 
%     	  corresponds to 
%		
%		  1515688724000,-1.63163357595,47.22395702655,1,0
%		  1515688724500,-1.63163357595,47.22395702655,1,0
%		  1515688725000,-1.63163357595,47.22395702655,1,0
%		  1515688725500,-1.63163357595,47.22395702655,1,0
%		  1515688726000,-1.63163357595,47.22395702655,1,0
%		  1515688726500,-1.63163357595,47.22395702655,1,0
%		  ...		
%
%     The lat/lon format has changed with respect to 2016 and 2017, now 
%     longitude comes first. Moreover, the building id has been removed.
%
%     The fifth column is now for the keypoints. Since the evaluation 
%     files does not include any reference to them, all the elements of
%     this column must be filled by 0. The id is automatically inserted
%     in this function.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ metric] = evaluate2018( solutionname )


% Load Ground Truth
GT              = dlmread(['GT/GT_evaluation_logfile.csv' ]);
timestamps      = GT(:,1);
groundtruth     = GT(:,2:4); 
referencepoints = GT(:,5);
indexestoinject = (GT(:,1)-1515688724000)/1000*2+1; % Apptimestamp 0 is 1515688724000

% Set the number of evaluation points and penalties
nsamples   = size(GT,1);
penalty1   = 15; % metros

% Load Competitor estimates
evaluationPath = csvread(['estimations/' solutionname '.csv']);

% Add keypoints
evaluationPath(indexestoinject,5) = [1:nsamples];

% Check Lat/Lon format. In 2019, we moved to LON/LAT but logfiles are in LAT/LON
if (evaluationPath(1,2)>40) &&(evaluationPath(1,3)<(-1)) 
    disp('Track 3 - Missmatch LON/LAT format') % 
    evaluationPath(:,2:3) = evaluationPath(:,[3,2]);
end

evaluationPath_keypoints = evaluationPath(evaluationPath(:,5)>0,:);


if sum(timestamps~=evaluationPath_keypoints)
  disp('Competitor provided less estimates than expected')
elseif sum(referencepoints~=evaluationPath_keypoints(:,5))
  disp('Reference points do not match')
else
    
    % harvesineDistance works with lat/lon format 
    results = [1000*harvesineDistance(groundtruth(:,[2,1]),...
                  evaluationPath_keypoints(:,[3,2])),...
                  penalty1 * abs(groundtruth(:,3)-evaluationPath_keypoints(:,4))];                    
    metric = round( prctile(results(:,1) +  results(:,2),75) *100 ) /100;
    
end

 
end

